@@ -1,13 +1,24 @@
 #!./perl
 
-# $Id: tied.pl,v 0.13 2002/06/12 06:41:55 ray Exp $
+# $Id: tied.pl,v 0.18 2006/10/08 03:37:29 ray Exp $
 #
 #  Copyright (c) 1995-1998, Raphael Manfredi
 #  
-#  You may redistribute only under the terms of the Artistic License,
-#  as specified in the README file that comes with the distribution.
+# You may redistribute and/or modify this file
+# under the same terms as Perl itself.
 #
 # $Log: tied.pl,v $
+# Revision 0.18  2006/10/08 03:37:29  ray
+# Commented out VERSION causes errors with DynaLoader in perl 5.6.1 (and
+# probably all earlier versions. It was removed.
+#
+# Revision 0.14  2003/09/07 22:02:36  ray
+# VERSION 0.15
+#
+# Revision 0.13.2.1  2003/09/07 21:51:13  ray
+# added support for unicode hash keys. This is only really a bug in 5.8.0 and
+# the test in t/03scalar supports this.
+#
 # Revision 0.13  2002/06/12 06:41:55  ray
 # VERSION 0.13
 #
@@ -39,7 +50,7 @@
 # Baseline for first beta release.
 #
 
-require 't/dump.pl';
+require './t/dump.pl';
 
 package TIED_HASH;
 
